#! /usr/bin/env python

import xml.etree.ElementTree as ET


class Variable_Name(object):

    def __init__(self,node):

        self.valid = False

        try:

            self.id = node.attrib['id']
            self.name = node.attrib['name']
            self.value = int(node.find('val').text)
            self.valid = True

        except:
            pass

    def __repr__(self):
        return 'Variable: ID {} Name {}, Value {}'.format(self.id,self.name,self.value)
    


#! /usr/bin/env python

from ..item_container import Item_Container
from .controller_base import Controller_Base


import logging
logger = logging.getLogger(__name__)


class Controller_Container (Item_Container):

    def __init__(self, controller):
        Item_Container.__init__(self,controller,'Controller')

    def start(self):

        controller = Controller_Base(self,'controller')
        self.add(controller,controller.id)

        self.items_retrieved = True

        return True
         
    def controller_event(self,propery,value):
        controller = self.get('controller')
        controller.set_property(propery,value)



#! /usr/bin/env python

''' 

Base Variable

Common to all elements returned from rest/nodes/variables

   properties = list of properties and values

'''

from .. item_base import Item_Base


class Variable_Base(Item_Base):

    def __init__(self, container, variable_info): 
        Item_Base.__init__(self,container,variable_info.id) # replaced once names are retrieved

        self.id = variable_info.id
        self.type = variable_info.type

        self.add_property ('init_value', variable_info.init_value)
        self.add_property ('value', variable_info.value)
        self.add_property ('time_set', variable_info.time_set)

    def get_index(self): # creates an index using var type and id
        return self.type+':'+self.id

    def __str__(self):
        return ("Variable: {} ; index {} ; value {}".format(self.name, self.get_index(), self.get_property('value')))

    def process_websocket_event(self,event):
        var_node = event.event_info_node.find('var')
        value = var_node.find('val').text
        time_set = var_node.find('ts').text

        self.set_property ('value',value)
        self.set_property ('time_set',time_set)

    def set_value(self,value):
        path = ('vars/set/' + self.type + '/' + self.id + '/' + str(value))
        return self.send_request(path)        

    def get_identifier(self):
        return self.self.get_index()       
        



#! /usr/bin/env python



from .device_base import Device_Base
from .device_insteon_base import Device_Insteon_Base

paddle_events = {'DON','DOF','DIM','BRT','DFON','DFOF'}

class Device_Insteon_Controller(Device_Base,Device_Insteon_Base):

    def __init__(self, container, device_info):
        Device_Base.__init__(self,container,'controller',device_info.name,device_info.address)
        Device_Insteon_Base.__init__(self, device_info)

        self.add_property('paddle_action')

    def process_websocket_event(self,event):
        if event.control in paddle_events: 
            self.set_property('paddle_action',event.control,True)